@@ -1,8 +1,27 @@
-import struct
-import select
+# SPDX-FileCopyrightText: 2013 Ole Martin Bjorndalen <ombdalen@gmail.com>
+#
+# SPDX-License-Identifier: MIT
+
+"""Read from /dev/input/js0 and return as dictionaries.
+
+If you have pygame it is easier and more portable to do something
+like::
+
+    import pygame.joystick
+    from pygame.event import event_name
+
+    pygame.init()
+    pygame.joystick.init()
+
+    js = pygame.joystick.Joystick(0)
+    js.init()
+
+    while True:
+        for event in pygame.event.get():
+            if event.axis == 0:
+                print(event)
 
 
-"""
 Init:
 
                   8 = init?
@@ -28,7 +47,7 @@ f0 fb 37 09 00 00 82 03
 f0 fb 37 09 00 00 82 04
 f0 fb 37 09 00 00 82 05
             --+--  |
-              |    1 = button, 2 = 
+              |    1 = button, 2 =
               |
             value (little endian unsigned)
 
@@ -59,11 +78,14 @@ The + stick has two modes. When the mode light is off, it sends axis
 Other axis have values from -32767 to 32767 as well.
 
 """
+import struct
+import select
 
 JS_EVENT_BUTTON = 0x1
 JS_EVENT_AXIS = 0x2
 JS_EVENT_INIT = 0x80
 
+
 def read_event(device):
     data = device.read(8)
 
@@ -77,19 +99,20 @@ def read_event(device):
     event['init'] = bool(event['type'] & JS_EVENT_INIT)
     event['type'] &= 0x7f  # Strip away the flag bits (JS_EVENT_INIT etc.)
     if event['type'] != JS_EVENT_BUTTON:
-        
         event['normalized_value'] = \
             float(event['value']) / 0x7fff  # Normalize to -1..1
 
     event['type'] = {1: 'button', 2: 'axis'}[event['type']]
-    
+
     return event
 
+
 def read_events(device_name):
     with open(device_name, 'rb') as device:
-        while 1:
+        while True:
             yield read_event(device)
 
+
 def panic(port):
     """
     Send "All Notes Off" and "Reset All Controllers" on
@@ -103,6 +126,7 @@ def panic(port):
             print(message)
             port.send(message)
 
+
 class Monophonic:
     # Todo: this assumes everything is on channel 0!
 
@@ -161,7 +185,7 @@ def play_scale(dev, out):
     program = 74
     out.send(mido.Message('program_change', program=program))
 
-    while 1:
+    while True:
         event = read_event(dev)
 
         if event['init']:
@@ -184,6 +208,7 @@ def play_scale(dev, out):
         #         pitch = int(event['normalized_value'] * pitch_scale)
         #         out.send(mido.Message('pitchwheel', pitch=pitch))
 
+
 def play_drums(dev, out):
     # http://www.midi.org/techspecs/gm1sound.php
     note_mapping = {
@@ -199,9 +224,9 @@ def play_drums(dev, out):
 
         9: 52,  # Chinese Cymbal
         10: 55,  # Splash Cymbal
-        }
+    }
 
-    while 1:
+    while True:
         event = read_event(dev)
         if event['init']:
             continue
@@ -217,7 +242,7 @@ def play_drums(dev, out):
                 type_ = 'note_on'
             else:
                 type_ = 'note_off'
-            
+
             note = note_mapping[button]
 
             message = mido.Message(type_, channel=9, note=note, velocity=64)
