@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2013 Ole Martin Bjorndalen <ombdalen@gmail.com>
+#
+# SPDX-License-Identifier: MIT
+
 """
 Mido ports for pygame.midi.
 
@@ -6,18 +10,19 @@ Pygame uses PortMidi, so this is perhaps not very useful.
 http://www.pygame.org/docs/ref/midi.html
 """
 
-from __future__ import absolute_import
 from pygame import midi
 from ..ports import BaseInput, BaseOutput
-from ..parser import parse
+
 
 def _get_device(device_id):
     keys = ['interface', 'name', 'is_input', 'is_output', 'opened']
     info = dict(zip(keys, midi.get_device_info(device_id)))
+    # TODO: correct encoding?
+    info['name'] = info['name'].decode('utf-8')
     info['id'] = device_id
-    info['name'] = info['name'].decode('utf-8') # Todo: correct encoding?
     return info
 
+
 def _get_default_device(get_input):
     if get_input:
         device_id = midi.get_default_input_id()
@@ -25,10 +30,11 @@ def _get_default_device(get_input):
         device_id = midi.get_default_output_id()
 
     if device_id < 0:
-        raise IOError('no default port found')
+        raise OSError('no default port found')
 
     return _get_device(device_id)
 
+
 def _get_named_device(name, get_input):
     # Look for the device by name and type (input / output)
     for device in get_devices():
@@ -44,11 +50,11 @@ def _get_named_device(name, get_input):
                 continue
 
         if device['opened']:
-            raise IOError('port already opened: {!r}'.format(name))
+            raise OSError(f'port already opened: {name!r}')
 
         return device
     else:
-        raise IOError('unknown port: {!r}'.format(name))
+        raise OSError(f'unknown port: {name!r}')
 
 
 def get_devices(**kwargs):
@@ -56,42 +62,45 @@ def get_devices(**kwargs):
     return [_get_device(device_id) for device_id in range(midi.get_count())]
 
 
-class PortCommon(object):
+class PortCommon:
     """
     Mixin with common things for input and output ports.
     """
+
     def _open(self, **kwargs):
-        if 'virtual' in kwargs:
-            raise IOError(
-                "virtual ports are not supported by the Pygame backend")
+        if kwargs.get('virtual'):
+            raise ValueError('virtual ports are not supported'
+                             ' by the Pygame backend')
+        elif kwargs.get('callback'):
+            raise ValueError('callbacks are not supported'
+                             ' by the Pygame backend')
 
         midi.init()
 
-        opening_input = hasattr(self, 'receive')
-
         if self.name is None:
-            device = _get_default_device(opening_input)
+            device = _get_default_device(self.is_input)
             self.name = device['name']
         else:
-            device = _get_named_device(self.name, opening_input)
+            device = _get_named_device(self.name, self.is_input)
 
         if device['opened']:
-            if opening_input:
+            if self.is_input:
                 devtype = 'input'
             else:
                 devtype = 'output'
-            raise IOError('{} port {!r} is already open'.format(devtype,
+            raise OSError('{} port {!r} is already open'.format(devtype,
                                                                 self.name))
-        if opening_input:
+        if self.is_input:
             self._port = midi.Input(device['id'])
         else:
             self._port = midi.Output(device['id'])
 
         self._device_type = 'Pygame/{}'.format(device['interface'])
-        
+
     def _close(self):
         self._port.close()
 
+
 class Input(PortCommon, BaseInput):
     """
     PortMidi Input port
@@ -104,17 +113,8 @@ class Input(PortCommon, BaseInput):
 
         while self._port.poll():
             bytes, time = self._port.read(1)[0]
-            if bytes[0] == 0xf0:
-                # Sysex support is broken.
-                # Only the first 3 data bytes arrive.
-                # It's best to ignore these.
-                continue
+            self._parser.feed(bytes)
 
-            message = parse(bytes)
-            if message:
-                # Time is just 0 or 1, so it's pointless.
-                # message.time = time
-                self._messages.append(message)
 
 class Output(PortCommon, BaseOutput):
     """
@@ -123,6 +123,11 @@ class Output(PortCommon, BaseOutput):
 
     def _send(self, message):
         if message.type == 'sysex':
-            self._port.write_sys_ex(midi.time(), message.bytes())
+            # Python 2 version of Pygame accepts a bytes or list here
+            # while Python 3 version requires bytes.
+            # According to the docs it should accept both so this may be
+            # a bug in Pygame:
+            # https://www.pygame.org/docs/ref/midi.html#pygame.midi.Output.write_sys_ex
+            self._port.write_sys_ex(midi.time(), bytes(message.bin()))
         else:
             self._port.write_short(*message.bytes())
